##
# name:      FooBar
# abstract:  Foo the Bar
# author:    Ingy döt Net <ingy@cpan.org>
# copyright: 2011
# license:   perl
# see:
# - Foo
# - Bar::Bar

package FooBar;
use 5.008003;

our $VERSION = '0.04';

1;

=head1 SYNOPSIS

    use FooBar;

=head1 DESCRIPTION

O HAI
